@@ -1,4 +1,5 @@
 """Define MQTT publishing."""
+# pylint: disable=unused-argument
 from __future__ import annotations
 
 import asyncio
@@ -41,6 +42,8 @@ from ecowitt2mqtt.const import (
     DATA_POINT_HOURLY_RAIN,
     DATA_POINT_HRAIN_PIEZO,
     DATA_POINT_HUMI_CO2,
+    DATA_POINT_HUMIDEX,
+    DATA_POINT_HUMIDEX_PERCEPTION,
     DATA_POINT_HUMIDITY_ABS,
     DATA_POINT_HUMIDITY_ABS_IN,
     DATA_POINT_LIGHTNING,
@@ -49,6 +52,8 @@ from ecowitt2mqtt.const import (
     DATA_POINT_MONTHLY_RAIN,
     DATA_POINT_MRAIN_PIEZO,
     DATA_POINT_RAIN_RATE,
+    DATA_POINT_RELATIVE_STRAIN_INDEX,
+    DATA_POINT_RELATIVE_STRAIN_INDEX_PERCEPTION,
     DATA_POINT_RUNTIME,
     DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_1,
     DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_2,
@@ -59,7 +64,6 @@ from ecowitt2mqtt.const import (
     DATA_POINT_SIMMER_INDEX,
     DATA_POINT_SIMMER_ZONE,
     DATA_POINT_SOLARRADIATION,
-    DATA_POINT_SOLARRADIATION_LUX,
     DATA_POINT_SOLARRADIATION_PERCEIVED,
     DATA_POINT_TF_CO2,
     DATA_POINT_THERMAL_PERCEPTION,
@@ -81,7 +85,7 @@ from ecowitt2mqtt.helpers.calculator.battery import (
 )
 from ecowitt2mqtt.helpers.device import Device
 from ecowitt2mqtt.helpers.publisher import MqttPublisher, generate_mqtt_payload
-from ecowitt2mqtt.helpers.typing import DataValueType
+from ecowitt2mqtt.helpers.typing import CalculatedValueType
 
 
 class DeviceClass(StrEnum):
@@ -92,6 +96,7 @@ class DeviceClass(StrEnum):
     DURATION = "duration"
     HUMIDITY = "humidity"
     ILLUMINANCE = "illuminance"
+    IRRADIANCE = "irradiance"
     MOISTURE = "moisture"
     PM10 = "pm10"
     PM25 = "pm25"
@@ -263,16 +268,23 @@ ENTITY_DESCRIPTIONS = {
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
+    DATA_POINT_HUMIDEX: EntityDescription(
+        icon="mdi:water",
+        state_class=StateClass.MEASUREMENT,
+    ),
+    DATA_POINT_HUMIDEX_PERCEPTION: EntityDescription(
+        icon="mdi:water",
+    ),
     DATA_POINT_HUMI_CO2: EntityDescription(
         device_class=DeviceClass.HUMIDITY,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_HUMIDITY_ABS: EntityDescription(
-        device_class=DeviceClass.HUMIDITY,
+        icon="mdi:water-percent",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_HUMIDITY_ABS_IN: EntityDescription(
-        device_class=DeviceClass.HUMIDITY,
+        icon="mdi:water-percent",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_LIGHTNING: EntityDescription(
@@ -318,21 +330,24 @@ ENTITY_DESCRIPTIONS = {
         icon="mdi:heat-wave",
     ),
     DATA_POINT_SOLARRADIATION: EntityDescription(
-        device_class=DeviceClass.ILLUMINANCE,
-        state_class=StateClass.MEASUREMENT,
-    ),
-    DATA_POINT_SOLARRADIATION_LUX: EntityDescription(
-        device_class=DeviceClass.ILLUMINANCE,
+        device_class=DeviceClass.IRRADIANCE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_SOLARRADIATION_PERCEIVED: EntityDescription(
-        device_class=DeviceClass.ILLUMINANCE,
+        icon="mdi:weather-sunny",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_RAIN_RATE: EntityDescription(
         icon="mdi:water",
         state_class=StateClass.MEASUREMENT,
     ),
+    DATA_POINT_RELATIVE_STRAIN_INDEX: EntityDescription(
+        icon="mdi:heat-wave",
+        state_class=StateClass.MEASUREMENT,
+    ),
+    DATA_POINT_RELATIVE_STRAIN_INDEX_PERCEPTION: EntityDescription(
+        icon="mdi:heat-wave",
+    ),
     DATA_POINT_RUNTIME: EntityDescription(
         device_class=DeviceClass.DURATION,
         entity_category=EntityCategory.DIAGNOSTIC,
@@ -378,37 +393,52 @@ STATE_CLASS_OVERRIDES = {
     DATA_POINT_YRAIN_PIEZO: StateClass.TOTAL,
 }
 
-STATE_UNKNOWN = "unknown"
 
-
-def get_availability_payload(data_point: CalculatedDataPoint) -> str:
+def get_availability_payload(
+    data_point: CalculatedDataPoint,
+) -> str:
     """Get the availability payload for a data point.
 
     Right now, this is hardcoded to always available.
+
+    Args:
+        data_point: A parsed CalculatedDataPoint object.
+
+    Returns:
+        An availability string.
     """
     return AVAILABILITY_ONLINE
 
 
-def get_state_payload(data_point: CalculatedDataPoint) -> DataValueType:
-    """Get the state payload for a data point."""
-    if data_point.value is None:
-        return STATE_UNKNOWN
-    return data_point.value
-
-
-class HomeAssistantDiscoveryPublisher(MqttPublisher):
+class HomeAssistantDiscoveryPublisher(
+    MqttPublisher
+):  # pylint: disable=too-few-public-methods
     """Define an MQTT publisher for the MQTT Discovery standard."""
 
     def __init__(self, config: Config, client: Client) -> None:
-        """Initialize."""
+        """Initialize.
+
+        Args:
+            config: A Config object.
+            client: An MQTT Client object.
+        """
         super().__init__(config, client)
 
         self._discovery_payloads: dict[str, HassDiscoveryPayload] = {}
 
-    def _generate_discovery_payload(
+    def _generate_discovery_payload(  # pylint: disable=too-many-branches
         self, device: Device, payload_key: str, data_point: CalculatedDataPoint
     ) -> HassDiscoveryPayload:
-        """Generate a discovery payload for an entity."""
+        """Generate a discovery payload for an entity.
+
+        Args:
+            device: A Device object.
+            payload_key: The Ecowitt payload key.
+            data_point: A CalculatedDataPoint object.
+
+        Returns:
+            A parsed HassDiscoveryPayload object.
+        """
         # Since batteries can be one of many different strategies, we calculate an
         # entity description at runtime:
         if data_point.data_point_key in (DATA_POINT_GLOB_BATT, DATA_POINT_GLOB_VOLT):
@@ -438,7 +468,7 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
                 "device": {
                     "identifiers": [device.unique_id],
                     "manufacturer": device.manufacturer,
-                    "model": device.name,
+                    "model": device.model,
                     "name": device.name,
                     "sw_version": device.station_type,
                 },
@@ -479,10 +509,17 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
 
         return payload
 
-    async def async_publish(self, data: dict[str, DataValueType]) -> None:
-        """Publish to MQTT."""
+    async def async_publish(self, data: dict[str, CalculatedValueType]) -> None:
+        """Publish to MQTT.
+
+        Args:
+            data: A data payload.
+
+        Raises:
+            MqttError: Raised on any MQTT error.
+        """
         processed_data = ProcessedData(self._config, data)
-        tasks = []
+        tasks: list[asyncio.Task] = []
 
         try:
             for payload_key, data_point in processed_data.output.items():
@@ -502,7 +539,7 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
                     ),
                     (
                         discovery_payload.payload["state_topic"],
-                        get_state_payload(data_point),
+                        data_point.value,
                     ),
                 ):
                     tasks.append(
